*#####################SETUP ALL INDEXES to be used in cross country regression##########################################
clear all

*Set Directory
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"

*#########################Employment Protection Index#################################
*#####################################################################################

import excel "${rawdata}\OECDEmploymentProtectionLegislationDatabase.xlsx", sheet("EPL dismissal regular workers") cellrange(A6:BB1108) firstrow

rename Year year
rename Country country
keep if year==2019
rename J regularworker

keep country year regularworker
tempfile reg
save `reg'

clear all
import excel "${rawdata}\OECDEmploymentProtectionLegislationDatabase.xlsx", sheet("EPL hiring temporary workers") cellrange(A6:BB1108) firstrow
rename Year year
rename Country country
keep if year==2019
rename Version3 tempworker

merge 1:1 country using "`reg.dta'"

keep country year regularworker tempworker

replace country="Slovakia" if country=="Slovak Republic"
replace country="Czechia" if country=="Czech Republic"
replace country="UK" if country=="United Kingdom"
replace country="US" if country=="United States" 

keep if country=="Austria" | country=="Belgium" |country=="Czechia" |country=="Canada" |country=="Denmark" |country=="Estonia" |country=="Finland" |country=="France" |country=="Germany" |country=="Greece" |country=="Hungary" |country=="Iceland" |country=="Ireland" |country=="Italy" |country=="Latvia" |country=="Lithuania" |country=="Luxembourg" |country=="Netherlands" |country=="Norway" |country=="Poland" |country=="Portugal" |country=="Romania" |country=="Slovakia" |country=="Slovenia" |country=="Spain" |country=="Sweden" |country=="Switzerland" |country=="UK" |country=="US" 
drop year
label variable tempworker "protection index temporary workers_2019"
label variable regularworker "protection index regular workers_2019"
tempfile empprotection
save `empprotection'

*#########################Telework Index #############################################
*#####################################################################################
clear all
import excel "${rawdata}\telecom.xlsx", sheet("Sheet1") firstrow
tempfile telecom
save `telecom'


*#########################Childcare Obligations#######################################
*#####################################################################################
clear all
import excel "${rawdata}\michele_paper.xlsx", sheet("Sheet1") firstrow clear
tempfile childcare_obligations
save `childcare_obligations'

*#########################School Closure##############################################
*#####################################################################################
clear all
insheet using "${rawdata}/covid_impact_education.csv", names clear 


keep if country=="Austria" | country=="Belgium" |country=="Czechia" |country=="Canada" |country=="Denmark" |country=="Estonia" |country=="Finland" |country=="France" |country=="Germany" |country=="Greece" |country=="Hungary" |country=="Iceland" |country=="Ireland" |country=="Italy" |country=="Latvia" |country=="Lithuania" |country=="Luxembourg" |country=="Netherlands" |country=="Norway" |country=="Poland" |country=="Portugal" |country=="Romania" |country=="Slovakia" |country=="Slovenia" |country=="Spain" |country=="Sweden" |country=="Switzerland" |country=="United Kingdom of Great Britain and Northern Ireland" |country=="United States of America" 

replace country="UK" if country=="United Kingdom of Great Britain and Northern Ireland"
replace country="US" if country=="United States of America"

*Generate a destring date version
gen date_destr=date(date,"DMY") 
format date_destr %td

gen year=year(date_destr) 
gen month=month(date_destr)
gen day=day(date_destr) 

keep if month==3 | month==4 | month==5 | month==6
* Drop if no status reported 
drop if status == "" 

* Number of days observed
bys iso: gen obs_all = _N 

* Academic break
by iso: gen temp = 1 if status == "Academic break" 
by iso: replace temp = 0 if status != "Academic break" 
by iso: egen temp2 = sum(temp) 
by iso: egen obs_acad_break = max(temp2) 
drop temp temp2 

* Number of days observed without academic breaks
bys iso: gen obs_wo_break = obs_all - obs_acad_break 

* index for some closure: closed weighted by 1 and partially open weighted by 1/2
by iso: gen temp = 1 if status == "Closed due to COVID-19" 
by iso: replace temp = 1/2 if status == "Partially open" 
by iso: replace temp = 0 if status != "Partially open" & status != "Closed due to COVID-19" 
by iso: egen tempsum = sum(temp)
by iso: egen index_closure = max(tempsum) 
by iso: gen index_closure_share = index_closure/obs_wo_break 
drop temp tempsum 

collapse index_closure_share , by(country)
label variable index_closure_share "weighted index of closed and partially closed(0.5) between march-june"

tempfile closure
save `closure'

merge 1:1 country using `childcare_obligations.dta'
drop _merge 
merge 1:1 country using `telecom.dta'
drop _merge 
merge 1:1 country using `empprotection.dta'
drop _merge 

save "${procdata}/ALL_indices.dta", replace





