
clear all
*Set Directory
adopath + "...\x12a" // Place seasonal adjustment files provided by Census Bureau and following instructions below. 
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"
gl output2   = "...\output2"

cd "${output2}/"

use "${procdata}/emp_quarter_ind.dta"



drop if year==2020 & q==3
sort country year q

drop if country=="Bulgaria" | country=="Croatia" | country=="Cyprus" | country=="Euro area - 19 countries  (from 2015)" | country=="European Union - 15 countries (1995-2004)" | country=="European Union - 27 countries (from 2020)" | country=="European Union - 28 countries (2013-2020)" | country=="Malta" | country=="Montenegro" | country=="North Macedonia" | country=="Serbia"

replace country="Germany" if country=="Germany (until 1990 former territory of the FRG)"
replace country="UK" if country=="United Kingdom"

drop if country=="Switzerland" & year<2010
drop if country=="Germany" & year==2020

local countrylist " Austria   Belgium  Czechia Denmark  Estonia Finland France Germany Greece Hungary Iceland Ireland Italy  Latvia  Lithuania Luxembourg  Netherlands  Norway Poland  Portugal  Romania  Slovakia  Slovenia  Spain  Sweden   Switzerland UK "

encode country, gen(c)
tsset c yq

drop extraterr extraterr_female extraterr_male //incomplete data
drop mining mining_female mining_male

*************************************************************************
local biglist "agri manu elec water construct trade transport accom info finan realest prof admin public educ health arts other hhs"
foreach b of local biglist{
replace `b'_male=`b'-`b'_female if `b'_male==.
replace `b'_female=`b'-`b'_male if `b'_female==.
}

*drop agri agri_male agri_female
*drop hhs hhs_female hhs_male
foreach b of local biglist{
bysort c: replace `b'=(L.`b'+F.`b')/2 if `b'==.
bysort c: replace `b'=(L.`b'+F2.`b')/2 if `b'==.
bysort c: replace `b'=(L.`b'+F.`b')/2 if `b'==.
bysort c: replace `b'=(L.`b'+F3.`b')/2 if `b'==.
bysort c: replace `b'=(L.`b'+F2.`b')/2 if `b'==.
bysort c: replace `b'=(L.`b'+F.`b')/2 if `b'==.
}

foreach b of local biglist{
bysort c: egen `b'_femshare=mean(`b'_female/`b')
bysort c: replace `b'_female=`b'*`b'_femshare if `b'_female==.
bysort c: replace `b'_male=`b'-`b'_female if `b'_male==.
drop `b'_femshare
}

************Small countries do not have all categories in all time series**************

replace water=0 if country=="Iceland" | country=="Estonia" | country=="Luxembourg"
replace water_male=0 if country=="Iceland" | country=="Estonia" | country=="Luxembourg"
replace water_female=0 if country=="Iceland" | country=="Estonia" | country=="Luxembourg"

replace realest=0 if country=="Iceland" | country=="Luxembourg"
replace realest_male=0 if country=="Iceland" | country=="Luxembourg"
replace realest_female=0 if country=="Iceland" | country=="Luxembourg"

replace elec=0 if country=="Luxembourg"
replace elec_male=0 if country=="Luxembourg"
replace elec_female=0 if country=="Luxembourg"

replace hhs=0 if country=="Sweden" | country=="Slovenia" | country=="Slovakia" | country=="Norway" | country=="Lithuania" | country=="Ireland" | country=="Iceland" | country=="Hungary" | country=="Estonia" | country=="Denmark" | country=="Belgium" | country=="Latvia"
replace hhs_male=0 if country=="Sweden" | country=="Slovenia" | country=="Slovakia" | country=="Norway" | country=="Lithuania" | country=="Ireland" | country=="Iceland" | country=="Hungary" | country=="Estonia" | country=="Denmark" | country=="Belgium" | country=="Latvia"
replace hhs_female=0 if country=="Sweden" | country=="Slovenia" | country=="Slovakia" | country=="Norway" | country=="Lithuania" | country=="Ireland" | country=="Iceland" | country=="Hungary" | country=="Estonia" | country=="Denmark" | country=="Belgium" | country=="Latvia"

replace arts=F.arts if arts==. //only relevant for Luxembourg 2008 q1 at this point
replace arts_male=F.arts if arts_male==. //only relevant for Luxembourg 2008 q1 at this point
replace arts_female=F.arts if arts_female==. //only relevant for Luxembourg 2008 q1 at this point


******No missing at this point

******Some aggregation

gen ttu=transport+trade+elec+water
gen ttu_male=transport_male+trade_male+elec_male+water_male
gen ttu_female=transport_female+trade_female+elec_female+water_female

gen bus_ad=prof+admin
gen bus_ad_male=prof_male+admin_male
gen bus_ad_female=prof_female+admin_female

gen ed_health=educ+health
gen ed_health_male=educ_male+health_male
gen ed_health_female=educ_female+health_female

gen leisure=arts+accom
gen leisure_male=arts_male+accom_male
gen leisure_female=arts_female+accom_female

gen fin_re=finan+realest
gen fin_re_female=finan_female+realest_female
gen fin_re_male=finan_male+realest_male

gen other_hh=other+hhs
gen other_hh_male=other_male+hhs_male
gen other_hh_female=other_female+hhs_female


local indlist " agri construct info public other_hh manu ttu bus_ad ed_health leisure fin_re" //10 main industries in BLS except agriculture mining

keep agri_male agri_female construct_male construct_female info_male info_female public_male public_female other_hh_male other_hh_female manu_male manu_female ttu_male ttu_female bus_ad_male bus_ad_female ed_health_male ed_health_female leisure_male leisure_female fin_re_female fin_re_male  country c year q yq 

local mylist "agri_male agri_female construct_male construct_female info_male info_female public_male public_female other_hh_male other_hh_female manu_male manu_female ttu_male ttu_female bus_ad_male bus_ad_female ed_health_male ed_health_female leisure_male leisure_female fin_re_female fin_re_male" 

tempfile ses
save `ses'

local countrylist1 " Austria  Belgium  Czechia Denmark Luxembourg  Czechia Denmark Luxembourg Estonia Finland France Germany Greece Hungary  "
*########This code does seasonal adjustment using the program X-13ARIMA-SEATS by Census Bureau: https://www.census.gov/srd/www/x13as/
*We use instructions by Ernie Tedeschi: https://medium.com/@ernietedeschi/how-to-get-x-13arima-seats-working-in-stata-for-windows-9e2e03b7e9c6
foreach c of local countrylist1{
use `ses.dta'
keep if country=="`c'"
foreach m of local mylist{
sax12 `m', satype(single) dtafile(`m')  
sax12im "`m'.out", ext(d11)
gen `m'_=`m'_d11 
}
tempfile `c'
save ``c''
clear
}
*This program has a shortcoming: It has a maximum limit on number of windows (seasonal adjustments) when it reaches the maximum it crashes. That's why, we have to divide the country list into two parts. 

window manage close viewer

local countrylist2 "Iceland Ireland Italy Latvia  Lithuania Netherlands  Norway Poland  Portugal  Romania  Slovakia  Slovenia  Spain  Sweden   Switzerland UK "
foreach c of local countrylist2{
use `ses.dta'
keep if country=="`c'"
foreach m of local mylist{
sax12 `m', satype(single) dtafile(`m')  
sax12im "`m'.out", ext(d11)
gen `m'_=`m'_d11 
}
tempfile `c'
save ``c''
clear
}

clear all
foreach c of local countrylist{
append using  ``c'.dta'
}


keep  agri_male_ agri_female_ construct_male_ construct_female_ info_male_ info_female_ public_male_ public_female_ other_hh_male_ other_hh_female_ manu_male_ manu_female_ ttu_male_ ttu_female_ bus_ad_male_ bus_ad_female_ ed_health_male_ ed_health_female_ leisure_male_ leisure_female_ fin_re_female_ fin_re_male_  c country year q yq
local varlist "agri_male agri_female construct_male construct_female info_male info_female public_male public_female other_hh_male other_hh_female manu_male manu_female ttu_male ttu_female bus_ad_male bus_ad_female ed_health_male ed_health_female leisure_male leisure_female fin_re_female fin_re_male"
foreach v of local varlist{
rename `v'_ `v'
}

save "${procdata}/ind_sa.dta", replace








