******************************POST-Covid Analysis***************************************************************
****************************************************************************************************************
****************************************************************************************************************
clear all
*Set Directory
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"
cd "${output}/"


clear all
use "${procdata}/hour_emp_gdp_quarter.dta"
tsset c yq
drop if year==2020 & q>=3
********************************************************************************
gen rel_index=female_index/male_index //cannot compare this measure across countries!!!!! level is meaningless but the change is. log change in rel index is the same as difference of log change in hours (women-men)
gen rel_emp=female_emp/male_emp
gen lgdp=log(gdp_sa)
gen lindex=log(all_index)

******************************MEN-WOMEN Quarterly Hours index****************************************************
*****************************************************************************************************************
*****************************************************************************************************************

preserve
keep if year>=2006
drop if year==2020 & q>=3 //2006q1-2020q2
summ yq
gen tick = 1 if yq == `r(max)'
local start = `r(min)'
local end   = `r(max)' + 4
keep if country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany" | country=="US" | country=="Canada"
xtline all_index, overlay addplot((scatter all_index yq if tick==1, mcolor(black) msymbol(point) mlabel(country) mlabsize(vsmall) mlabcolor(black))) legend(off) ylab(,nogrid) graphregion(color(white)) tlabel(`start'(12)`end', labsize(small)) xlabel() xtitle("") ytitle("Hours Index") name(index, replace)
graph export index_6.png, replace

tsfilter hp hour_cycle=lindex, smooth(1600)

xtline hour_cycle, overlay addplot((scatter hour_cycle yq if tick==1, mcolor(black) msymbol(point) mlabel(country) mlabsize(vsmall) mlabcolor(black) mlabposition(5))) legend(off) ylab(,nogrid) graphregion(color(white)) tlabel(`start'(12)`end', labsize(small)) xlabel() xtitle("") ytitle("Hours Index") name(s, replace)
graph export index_cycle_6.png, replace

tsfilter hp gdp_cycle=lgdp, smooth(1600)
xtline gdp_cycle, overlay addplot((scatter gdp_cycle yq if tick==1, mcolor(black) msymbol(point) mlabel(country) mlabsize(vsmall) mlabcolor(black))) legend(off) ylab(,nogrid) graphregion(color(white)) tlabel(`start'(12)`end', labsize(small)) xlabel() xtitle("") ytitle("Real GDP") name(c, replace)
graph export gdp_cycle.png, replace
restore


*************Plot GDP per capita in a long time series*********

preserve
keep if year>=1995
summ yq
gen tick = 1 if yq == `r(max)'
local start = `r(min)'
local end   = `r(max)' + 7
keep if country=="UK" | country=="Spain" | country=="Netherlands" | country=="Germany" | country=="US" | country=="Canada"
xtline gdppercap, overlay addplot((scatter gdppercap yq if tick==1, mcolor(black) msymbol(point) mlabel(country) mlabsize(vsmall) mlabcolor(black))) legend(off) ylab(,nogrid) graphregion(color(white)) tlabel(`start'(12)`end', labsize(small)) xlabel() xtitle("") ytitle("Real GDP per cap") name(percap, replace)

graph export gdp_pc_95.png, replace
restore
***************************************************************************
*###################Create cross country dataset for scatter plots and regressions//remove the time dimension################################

gen precovid_relhour=log(rel_index) if year==2019 & q==4
gen postcovid_relhour=log(rel_index) if year==2020 & q==2
gen precovid_allhour=log(all_index) if year==2019 & q==4
gen postcovid_allhour=log(all_index) if year==2020 & q==2

gen precovid_relemp=log(rel_emp) if year==2019 & q==4
gen postcovid_relemp=log(rel_emp) if year==2020 & q==2
gen precovid_allemp=log(all_emp) if year==2019 & q==4
gen postcovid_allemp=log(all_emp) if year==2020 & q==2

******Our own gdp adjustment 
gen precovid_gdp=log(gdp_sa) if year==2019 & q==4
gen postcovid_gdp=log(gdp_sa) if year==2020 & q==2

collapse precovid_relhour postcovid_relhour precovid_allhour postcovid_allhour precovid_relemp postcovid_relemp precovid_allemp postcovid_allemp precovid_gdp postcovid_gdp, by(country)

gen change_relhour=postcovid_relhour-precovid_relhour
gen change_allhour=postcovid_allhour-precovid_allhour
gen change_relemp=postcovid_relemp-precovid_relemp
gen change_allemp=postcovid_allemp-precovid_allemp
gen change_gdp=postcovid_gdp-precovid_gdp

keep change_relhour change_allhour change_relemp change_allemp change_gdp country 
save "${procdata}/postcovid.dta", replace




