*******************Calculates yearly averages of hours worked for subgroups and 9 countries*************
*******************************************************************************************************
clear all

*Set Directory

gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"

cd "${output}"

**********Sample of All Children below 14*********

use "${rawdata}/LFS_27countries_98_19.dta"
keep if refyear==2019
keep if country=="DE" | country=="UK" | country=="NL" | country=="ES"
keep if age<=12
gen id=hhmoth
gen fid=hhfath
rename age c_age
keep c_age id qhhnum fid country
tempfile children
save `children'

********Sample of All Women above 14**************
clear all
use "${rawdata}/LFS_27countries_98_19.dta"
keep if refyear==2019
keep if country=="DE" | country=="UK" | country=="NL" | country=="ES"
gen id=hhseqnum 
keep if age>12
keep if sex==2
merge 1:m qhhnum country id using `children.dta' //in this sample we observe adults and if they have a matched child_0_14
sort qhhnum country

gen mother_14=.
replace mother_14=1 if _merge==3 
replace mother_14=0 if _merge!=3 

bysort country qhhnum id: egen min_age=min(c_age) if mother_14==1
gen c=1 if mother_14==1
bysort country qhhnum id: egen num_kid=sum(c) if sex==2

gen mother_5=.
replace mother_5=1 if min_age<=2  //age 0-4
replace mother_5=0 if min_age>2  

gen mother_6_14=.
replace mother_6_14=1 if min_age>=7 & min_age<=12  //age 0-4
replace mother_6_14=0 if (min_age<7 ) | (min_age>12 )

***Now there are dublicates because of multiple children per mother
sort qhhnum country id
quietly by qhhnum country id:  gen dup = cond(_N==1,0,_n)
drop if dup>1

drop c_age _merge dup 
tempfile women
save `women'

********Sample of All Men above 14**************
clear all
use "${rawdata}/LFS_27countries_98_19.dta"
keep if refyear==2019
keep if country=="DE" | country=="UK" | country=="NL" | country=="ES"
gen fid=hhseqnum 
keep if age>12
keep if sex==1
merge 1:m qhhnum country fid using `children.dta' //in this sample we observe adults and if they have a matched child_0_14
sort qhhnum country
gen father_14=.
replace father_14=1 if _merge==3 
replace father_14=0 if _merge!=3 
sort qhhnum country fid
quietly by qhhnum country fid:  gen dup = cond(_N==1,0,_n)
drop if dup>1
drop c_age _merge dup 

append using `women.dta'

*****Sample Selection**************************************************
keep if age>=27 & age<=52 //age 25-54

*****DEFINE VARIABLES**************************************************

rename refyear year
rename hourreas reason_diffwork
rename nowkreas reason_nowork

**********************************************************
gen male=.
replace male=1 if sex==1
replace male=0 if sex==2

gen female=.
replace female=1 if sex==2
replace female=0 if sex==1 

gen employed=. 
replace employed=1 if ilostat==1
replace employed=0 if ilostat==2 | ilostat==3 | ilostat==4 //unemployed, inactive, military

gen married=. 
replace married=1 if marstat==2
replace married=0 if marstat!=2 //unmarried

*******HOURS VARIABLES*************************************
gen hours_1=. //main job
replace hours_1= hwactual if hwactual>=0 & hwactual<=98  // new definition to capture positive hours even if not employed; gives exactly the same estimate as there are no positive hours if not employed
replace hours_1=. if (hwactual==99 | hwactual==.) & (wstator==1) & employed==1 //employed, claim worked but undefined
replace hours_1=0 if (hwactual==99 | hwactual==.) & (wstator==2 | wstator==3 | wstator==4| wstator==5) //did not work but undefined 

keep if hours_1!=. & hours_1!=99 // to go to the next step this is needed otherwise undefined values will be true values

replace hours_1=hwusual if (hours_1<hwusual) & ( reason_diffwork==11 | reason_diffwork==12 | reason_nowork==7 ) //if worked less due to holidays (bank holidays, annual holidays) or no work at all due to holidays
replace hours_1=hwusual if (hours_1<hwusual) & ( reason_nowork==0 ) & country=="UK" & year==2001 //bad weather is unusually high in that year a possible switch with holidays as discussed by Nicola. 
******************SELECTION************************************************
*Everyone whose actual hours are defined including people who do not work (0s) 
keep if hours_1!=. & hours_1!=99 //only if main job is well defined, this cleaning cleans only if we have to use usual hours and it happens to be undefined
****************************************************************************
gen hours_2=0 //secondjob
replace hours_2=hwactua2 if hwactua2>=0 & hwactua2<=98 
****************************************************************************
gen hours=hours_1+hours_2 //all jobs   MAIN VARIABLE
label variable hours "hours with extensive margin_ MAIN VARIABLE"
label variable hours_1 "hours main job"
label variable hours_2 "hours additional jobs"

*****DEFINE VARIABLES**************************************************

***********Presence of Any Children************************************
gen child_0_2=. //presence of children 0-2
replace child_0_2=1 if hhnbch2>=1 & hhnbch2<99
replace child_0_2=0 if hhnbch2==0
replace child_0_2=. if hhnbch2==99 //not a private HH, few observations

gen child_3_5=. //presence of children 3-5
replace child_3_5=1 if hhnbch5>=1 & hhnbch5<99
replace child_3_5=0 if hhnbch5==0
replace child_3_5=. if hhnbch5==99 //not a private HH, few observations (626)

gen child_6_8=. //presence of children 6-8
replace child_6_8=1 if hhnbch8>=1 & hhnbch8<99
replace child_6_8=0 if hhnbch8==0
replace child_6_8=. if hhnbch8==99 //not a private HH, few observations

gen child_9_11=. //presence of children 9-11
replace child_9_11=1 if hhnbch11>=1 & hhnbch11<99
replace child_9_11=0 if hhnbch11==0
replace child_9_11=. if hhnbch11==99 //not a private HH, few observations

gen child_12_14=. //presence of children 12-14
replace child_12_14=1 if hhnbch14>=1 & hhnbch14<99
replace child_12_14=0 if hhnbch14==0
replace child_12_14=. if hhnbch14==99 //not a private HH, few observations


**************************************************************************
******MORE AGGEGATED MEASURES**********************************************
gen child_0_14=.
replace child_0_14=1 if (child_0_2==1 | child_3_5==1 | child_6_8==1 | child_9_11==1 | child_12_14==1)
replace child_0_14=0 if (child_0_2==0 & child_3_5==0 & child_6_8==0 & child_9_11==0 & child_12_14==0)

***********************************************************************


**************************************************************************
*1-) Share of employed individuals living with kids // Table A1 in the Appendix

bysort country: asgen sh_0_14_emp=child_0_14 if employed==1, w(coeff) //column1

*Share of mothers //single mothers in the labor force
gen emp_moth=.
replace emp_moth=1 if mother_14==1 & employed==1
replace emp_moth=0 if (mother_14==0 & employed==1) | (female==0 & employed==1)
bysort country: asgen sh_moth_lf=emp_moth, w(coeff) //column2

gen emp_singmoth=.
replace emp_singmoth=1 if mother_14==1 & employed==1 & hhcomp==11
replace emp_singmoth=0 if (mother_14==0 & employed==1) | (female==0 & employed==1)
bysort country: asgen sh_singmoth_lf=emp_singmoth, w(coeff) //column3

*************************************************************************

**************************************************************************
*2-) Labor supply of women and men with kids vs no kids (intensive extensive) Table A2 in the Appendix
bysort country: asgen ls_nonmother=hours if mother_14==0, w(coeff)
bysort country: asgen ls_sing_mother_6_14=hours if hhcomp==11 & mother_6_14==1, w(coeff)
bysort country: asgen ls_couple_mother_6_14=hours if hhcomp==21 & mother_6_14==1, w(coeff)
bysort country: asgen ls_sing_mother_0_5=hours if hhcomp==11 & mother_5==1, w(coeff)
bysort country: asgen ls_couple_mother_0_5=hours if hhcomp==21 & mother_5==1, w(coeff)

bysort country: asgen ls_nonfather=hours if father_14==0, w(coeff)
bysort country: asgen ls_father=hours if father_14==1, w(coeff)



collapse sh_0_14_emp sh_moth_lf sh_singmoth_lf ls_nonmother  ls_sing_mother_6_14 ls_couple_mother_6_14 ls_sing_mother_0_5 ls_couple_mother_0_5 ls_nonfather ls_father, by(country)

order country sh_0_14_emp sh_moth_lf sh_singmoth_lf ls_sing_mother_0_5 ls_couple_mother_0_5 ls_sing_mother_6_14 ls_couple_mother_6_14 ls_nonmother ls_father ls_nonfather

export excel using "children_jan", sheetreplace firstrow(variables)

*************************************************************************************


