*******************Calculates yearly averages of hours worked for subgroups and 6 countries*************
*******************************************************************************************************
clear all

***##########################6 Country Time Series Analysis#####################*********************
*####################################################################################################
*this file produces Table 1 and Figure A1 in the paper
*Set Directory
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"


cd "${output}"
use "${rawdata}/4countries_98_19.dta" //hours variable is cleaned in the main file of cleaning 27 country 98-19 

*****DEFINE VARIABLES**************************************************
gen married=. 
replace married=1 if marstat==2
replace married=0 if marstat!=2 //unmarried

keep sex year country coeff male female married hours

bysort country year: asgen mhours=hours,w(coeff)
bysort country year: asgen hours_male=hours if male==1,w(coeff)
bysort country year: asgen hours_female=hours if male==0,w(coeff)


bysort country year: asgen hours_marriedmale=hours if male==1 & married==1, w(coeff)
bysort country year: asgen hours_marriedfemale=hours if male==0 & married==1, w(coeff)
bysort country year: asgen hours_singlemale=hours if male==1 & married==0, w(coeff)
bysort country year: asgen hours_singlefemale=hours if male==0 & married==0, w(coeff)

*to calculate the hour share of each group
bysort country year: egen thours_male=total(hours*coeff) if male==1
bysort country year: egen thours_female=total(hours*coeff) if male==0
bysort country year: egen thours_marriedmale=total(hours*coeff) if male==1 & married==1
bysort country year: egen thours_marriedfemale=total(hours*coeff) if male==0 & married==1
bysort country year: egen thours_singlemale=total(hours*coeff) if male==1 & married==0
bysort country year: egen thours_singlefemale=total(hours*coeff) if male==0 & married==0
bysort country year: egen thours=total(hours*coeff)



collapse thours_male thours_female thours_marriedmale thours_marriedfemale  thours_singlemale thours_singlefemale thours mhours hours_male hours_female hours_marriedmale hours_marriedfemale hours_singlemale hours_singlefemale, by(year country)

replace country="Germany" if country=="DE"
replace country="Spain" if country=="ES"
replace country="Netherlands" if country=="NL"

*********This files are already harmonized***************
append using "${procdata}/US_aggregates.dta"
append using "${procdata}/Canada_aggregates.dta"

merge 1:1 year country using "${procdata}\gdp_annual.dta"
drop if _merge!=3
drop _merge

********Year selection***********************************
keep if year>=1998 & year<=2019

drop memp emp_male emp_female //irrelevant
rename mhours hours_all


gen l_gdp=log(realgdp)
encode country, gen(c)
tsset c year

****Hours share
gen male_share=100*thours_male/thours
gen female_share=100*thours_female/thours
gen marriedmale_share=100*thours_marriedmale/thours
gen marriedfemale_share=100*thours_marriedfemale/thours
gen singlemale_share=100*thours_singlemale/thours
gen singlefemale_share=100*thours_singlefemale/thours

*###############################################################
****One can use the below ready data to without the microdata to produce the numbers in the table
preserve
keep hours_all hours_male hours_female hours_marriedmale hours_marriedfemale hours_singlemale hours_singlefemale realgdp male_share female_share marriedmale_share marriedfemale_share singlemale_share singlefemale_share year country
save "${procdata}/data_table1.dta", replace
restore
*#################################################################


local mylist "all male female marriedmale marriedfemale singlemale singlefemale"
foreach m of local mylist{
gen l_hours_`m'=log(hours_`m')
}

local countrylist "Germany UK Spain Netherlands US Canada"

tsfilter hp gdp_cycle=l_gdp, smooth(6.25)
foreach m of local mylist{
tsfilter hp hours_`m'_cycle=l_hours_`m', smooth(6.25)
}




****Total volatility
foreach m of local mylist{
bysort c: egen sd_`m'=sd(hours_`m'_cycle)
replace sd_`m'=100*sd_`m'
}

****Cyclical volatility
foreach m of local mylist{
gen cyc_`m'=.
}

foreach c of local countrylist{
foreach m of local mylist{
reg hours_`m'_cycle gdp_cycle if country=="`c'"
predict `m'_hat if country=="`c'",xb
egen c_`m'=sd(`m'_hat) if country=="`c'"
replace cyc_`m'=100*c_`m' if country=="`c'"
drop `m'_hat c_`m'
}
}

*Volatility share****
local slist "male female marriedmale marriedfemale singlemale singlefemale"

foreach m of local slist{
gen volshare_`m'=.
bysort c: replace volshare_`m'=(cyc_`m'*`m'_share)/cyc_all
}
*Normalize volatility share***
gen totmw_share=volshare_male+volshare_female
gen totmwsm_share=volshare_marriedmale+volshare_marriedfemale+volshare_singlemale+volshare_singlefemale
replace volshare_male=100*volshare_male/totmw_share
replace volshare_female=100*volshare_female/totmw_share
replace volshare_marriedfemale=100*volshare_marriedfemale/totmwsm_share
replace volshare_marriedmale=100*volshare_marriedmale/totmwsm_share
replace volshare_singlefemale=100*volshare_singlefemale/totmwsm_share
replace volshare_singlemale=100*volshare_singlemale/totmwsm_share


tempfile a
save `a'

*****Figure A1 in the paper
foreach c of local countrylist{
use `a.dta'
keep if country=="`c'"
local sdmm : di %4.3f sd_marriedmale
local sdmw : di %4.3f sd_marriedfemale
local sdsm : di %4.3f sd_singlemale
local sdsw : di %4.3f sd_singlefemale

twoway (line hours_marriedfemale_cycle year,lcolor("red")) (line hours_marriedmale_cycle year,lcolor("black")) (line hours_singlefemale_cycle year,lcolor("red") lpattern(dash)) (line hours_singlemale_cycle year,lcolor("black") lpattern(dash)) , name(s_m_h_`c', replace) legend(label(1 " Married Women Cycle") label(2 " Married Men Cycle") label(3 " Single Women Cycle") label(4 " Single Men Cycle") r(2)) ylabel(-0.04 (0.02) 0.04) title("`c'") xtitle("") ytitle("Log Change in Hours Cycles") text(0.015 2014 "sd_mwomen=`sdmw'""sd_mmen=`sdmm'"  "sd_swomen=`sdsw'""sd_smen=`sdsm'", size(small) placement(ne) box fcolor(white) lwidth(medium)) ylab(,nogrid) graphregion(color(white)) 

graph export single_married_exthours_`c'.png, replace
clear
}

use `a.dta'

****************************1998-2019 Table Numbers and Figures**************************************************
******************************************************************************************************
***************************************************************************************************
******table 1 in the paper
putexcel set table1.xlsx, sheet(table1, replace) modify

putexcel A2 = "`c'"
putexcel A3 = "Total Volatility"
putexcel A11= "Cyclical Volatility"
putexcel A19 = "Hours Share"
putexcel A27 = "Volatility Share"
putexcel B1:D1 = "All", merge hcenter
putexcel E1:F1 = "Married", merge hcenter
putexcel G1:H1 = "Single", merge hcenter
putexcel B2="Total", hcenter
putexcel C2="Women", hcenter
putexcel E2="Women", hcenter
putexcel G2="Women", hcenter
putexcel D2="Men", hcenter
putexcel F2="Men", hcenter
putexcel H2="Men", hcenter

putexcel A4="Canada"
putexcel A12="Canada"
putexcel A20="Canada"
putexcel A28="Canada"
putexcel A5="Germany"
putexcel A13="Germany"
putexcel A21="Germany"
putexcel A29="Germany"
putexcel A6="Netherlands"
putexcel A14="Netherlands"
putexcel A22="Netherlands"
putexcel A30="Netherlands"
putexcel A7="Spain"
putexcel A15="Spain"
putexcel A23="Spain"
putexcel A31="Spain"
putexcel A8="UK"
putexcel A16="UK"
putexcel A24="UK"
putexcel A32="UK"
putexcel A9="US"
putexcel A17="US"
putexcel A25="US"
putexcel A33="US"


preserve
collapse sd_all sd_female sd_male sd_marriedfemale sd_marriedmale sd_singlefemale sd_singlemale, by(country)
format sd_all sd_female sd_male sd_marriedfemale sd_marriedmale sd_singlefemale sd_singlemale %6.2f
mkmat sd_all sd_female sd_male sd_marriedfemale sd_marriedmale sd_singlefemale sd_singlemale , matrix(mat_data)
putexcel B4  = matrix(mat_data)
restore

preserve
collapse cyc_all cyc_female cyc_male cyc_marriedfemale cyc_marriedmale cyc_singlefemale cyc_singlemale, by(country)
mkmat cyc_all cyc_female cyc_male cyc_marriedfemale cyc_marriedmale cyc_singlefemale cyc_singlemale, matrix(mat_data)
putexcel B12  = matrix(mat_data)
restore

preserve
collapse female_share male_share marriedfemale_share marriedmale_share singlefemale_share singlemale_share, by(country) 
mkmat female_share male_share marriedfemale_share marriedmale_share singlefemale_share singlemale_share, matrix(mat_data)
putexcel C20  = matrix(mat_data)
restore

preserve
collapse volshare_female volshare_male volshare_marriedfemale volshare_marriedmale volshare_singlefemale volshare_singlemale, by(country)
mkmat volshare_female volshare_male volshare_marriedfemale volshare_marriedmale volshare_singlefemale volshare_singlemale, matrix(mat_data)
putexcel C28  = matrix(mat_data)
restore




