*******************************************************************************************************
*******************Setup quarterly Employment for US and Canada ***************
*******************************************************************************************************

clear all

*Set Directory
adopath + "...\x12a" // Place seasonal adjustment files provided by Census Bureau and following instructions below. 
gl rawdata  = "...\rawdata"
gl procdata = "...\procdata"
gl output   = "...\output"
gl output2   = "...\output2"

cd "${output2}/"

use "${rawdata}\EMP_TEMP_SEX_AGE_NB_Q-filtered-2021-01-28.dta"

keep ref_area_label sex_label classif1_label time obs_value
rename ref_area country
replace country="US" if country=="United States"
gen year=.
replace year= real(substr(time, -6, 4)) 
gen q=.
replace q= real(substr(time, -1,1 ))
gen yq = yq(year, q)
format yq %tq

sort country yq

bysort country time: egen all_emp=sum(obs_value) if sex_label=="Sex: Total" //to calculate 20-64

bysort country time: egen female_emp=sum(obs_value) if sex_label=="Sex: Female"

bysort country time: egen male_emp=sum(obs_value) if sex_label=="Sex: Male"

collapse all_emp female_emp male_emp year q, by(country yq)
encode country, gen(c)
tsset c yq

****There is a clear problem with 2012 q2 in the US*****
****Numbers are extremely low for no reason*************
****Extrapolate that with the average of lag and forward
replace all_emp=(L.all_emp+F.all_emp)/2 if country=="US" & year==2012 & q==2
replace male_emp=(L.male_emp+F.male_emp)/2 if country=="US" & year==2012 & q==2
replace female_emp=(L.female_emp+F.female_emp)/2 if country=="US" & year==2012 & q==2

tempfile ilo
save `ilo'

cd "${output2}"

local countrylist "US Canada"
local mylist "female_emp male_emp"
*########This code does seasonal adjustment using the program X-13ARIMA-SEATS by Census Bureau: https://www.census.gov/srd/www/x13as/
*We use instructions by Ernie Tedeschi: https://medium.com/@ernietedeschi/how-to-get-x-13arima-seats-working-in-stata-for-windows-9e2e03b7e9c6
foreach c of local countrylist{
use `ilo.dta'
keep if country=="`c'"
foreach m of local mylist{
sax12 `m', satype(single) dtafile(`m')  
sax12im "`m'.out", ext(d11)
gen `m'_sa=`m'_d11 
}
tempfile `c'
save ``c''
clear all
}

foreach c of local countrylist{
append using ``c'.dta'
}

keep country yq year q c female_emp_sa male_emp_sa
rename female_emp_sa female_emp
rename male_emp_sa male_emp
gen all_emp=female_emp+male_emp

label variable all_emp "All 20-64 seasonally adjusted"
label variable male_emp "Male 20-64 seasonally adjusted"
label variable female_emp "Female 20-64 seasonally adjusted"
save "${procdata}/ilostat_US_Canada_emp.dta", replace





